==> edicom_0.1-1.tar.gz: edicom-0.1/src/mainwindow.h <==
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QThread>
#include <QDirModel>
#include <QGridLayout>
#include <QWidget>
#include <QTabWidget>
#include <QScrollArea>
#include "codeeditor.h"
#include "gdbthread.h"
#include "gdboutput.h"
#include "scanfthread.h"
#include "highlighter.h"
#include "flags.h"
#include "codeeditor.h"
#include "Terminal/outputthread.h"
#include "Terminal/terminal.h"
#include "Common.h"
#include "rceventhandler.h"

#define MAXTAB 10
namespace Ui
{
    class MainWindow;
}
class MyThread;
class MainWindow : public QMainWindow
{
    Q_OBJECT
public:
    MainWindow(int argc,char *argv[],QWidget *parent = 0);
    ~MainWindow();
    void init();

public slots:
    void debug();
    bool maybeSave(int i=-1);
    bool fileSave();
    bool fileSaveAs();
    void fileNew();
    void open(QString fname="");
    void closeEvent(QCloseEvent *event);
    void run();
    void compile();
    void highlightDebuggingLine(int linenum,int color=0);
    void addBreakPoint();
    void showAbout();
    void updateLineNumber(QString str);
    void stopDebug();
    void updateDisplay(QString str);
    void showScanDialog(QString str);
    void terminalExiting();
    void showFullScreenSlot();
public:
    GdbThread gdbThread;
    Terminal *t;
    Ui::MainWindow *ui;

    QString outputString;
    Flags flags;
    QDirModel model;
    ScanfThread scanfThread;
    GdbOutput gdbOutput;
    OutputThread outputThread;
    QPushButton *m_dbButton;
    const QIcon m_fsIcon;

    QList <QWidget *> tab;
    QList <Highlighter *> highlighter;
    QList <QGridLayout *> gridLayout;
    QList <QGridLayout *> gridLayout2;
    QList <CodeEditor *> displayArea;
    QList <QScrollArea *> scrollArea;
    QList <QString > fileName;
    QList <QWidget *> scrollAreaWidgetContents;

    int compiledTab;
    int currentFileTab;
    RCEventHandler *listEvHandler;

    QMenu *watchMenu;
    QAction *actionNewWatch;
    QAction *actionDeleteWatch;

    QStringList watchVariablesList;

private slots:
    void documentModified();
    void closeTab(int index);
    void textUndo();
    void textRedo();
    void insertKeyword();
    void cancelButtonClicked();
    void keywordSelected(QModelIndex index);
    void upPushButtonSlot();
    void downPushButtonSlot();
    void deleteKeywordList();
    void addKeywordList();
    void enableDebugingMode();

    void textCopy();
    void textCut();
    void textPaste();
    void rightButtonClicked(const QPoint &p);
    void setWatchWindowVisible();
    void addWatchItem();
    void deleteWatchItem();
    void shareOnlineSlot();
};
#endif // MAINWINDOW_H

==> edicom_0.1-7.tar.gz: edicom-0.1/src/mainwindow.h <==
/*
 * This file is part of edicom application
 *
 * Copyright (C) 2010 Sugnan Prabhu S <sugnan.prabhu@gmail.com>
 *
 * Contact: Sugnan Prabhu S <sugnan.prabhu@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QThread>
#include <QDirModel>
#include <QGridLayout>
#include <QWidget>
#include <QTabWidget>
#include <QScrollArea>
#include "codeeditor.h"
#include "gdbthread.h"
#include "gdboutput.h"
#include "scanfthread.h"
#include "highlighter.h"
#include "flags.h"
#include "codeeditor.h"
#include "Terminal/outputthread.h"
#include "Terminal/terminal.h"
#include "Common.h"
#include "rceventhandler.h"

#define MAXTAB 10
namespace Ui
{
    class MainWindow;
}
class MyThread;
class MainWindow : public QMainWindow
{
    Q_OBJECT
public:
    MainWindow(int argc,char *argv[],QWidget *parent = 0);
    ~MainWindow();
    void init();

public slots:
    void debug();
    bool maybeSave(int i=-1);
    bool fileSave(bool diffFile=false);
    bool fileSaveAs();
    void fileNew();
    void open(QString fname="");
    void closeEvent(QCloseEvent *event);
    void run();
    void compile();
    void highlightDebuggingLine(int linenum,int color=0);
    void showAbout();
    void updateLineNumber(QString str);
    void stopDebug();
    void updateDisplay(QString str);
    void showScanDialog(QString str);
    void terminalExiting();
    void showFullScreenSlot();
    void setBreakPoint(int lineNumber,bool setFlag,QString toFile="");
public:
    GdbThread gdbThread;
    Terminal *t;
    Ui::MainWindow *ui;

    QString outputString;
    Flags flags;
    QDirModel model;
    ScanfThread scanfThread;
    GdbOutput gdbOutput;
    OutputThread outputThread;
    QPushButton *m_dbButton;
    const QIcon m_fsIcon;

    QList <QWidget *> tab;
    QList <Highlighter *> highlighter;
    QList <QGridLayout *> gridLayout;
    QList <QGridLayout *> gridLayout2;
    QList <CodeEditor *> displayArea;
    QList <QScrollArea *> scrollArea;
    QList <QString > fileName;
    QList <QWidget *> scrollAreaWidgetContents;

    int compiledTab;
    int currentFileTab;
    RCEventHandler *listEvHandler;

    QMenu *watchMenu;
    QAction *actionNewWatch;
    QAction *actionDeleteWatch;

    QStringList watchVariablesList;

private slots:
    void documentModified();
    void closeTab(int index);
    void textUndo();
    void textRedo();
    void insertKeyword();
    void cancelButtonClicked();
    void keywordSelected(QModelIndex index);
    void upPushButtonSlot();
    void downPushButtonSlot();
    void deleteKeywordList();
    void addKeywordList();
    void enableDebugingMode();

    void textCopy();
    void textCut();
    void textPaste();
    void rightButtonClicked(const QPoint &p);
    void setWatchWindowVisible();
    void addWatchItem();
    void deleteWatchItem();
    void shareOnlineSlot();
    void showSettingsDialog();
};
#endif // MAINWINDOW_H
